@@ -3,14 +3,18 @@ import whisper
 import moviepy.editor as mp
 from moviepy.editor import VideoFileClip
 from .config import DEFAULT_PATHS
-from abstract_utilities import get_logFile
+from abstract_utilities import get_logFile,SingletonMeta
 logger = get_logFile(__name__)
-
 DEFAULT_WHISPER_MODEL_PATH = DEFAULT_PATHS["whisper"]
-
+class whisperManager(metaclass=SingletonMeta):
+    def __init__(self,module_size: str = "base", whisper_model_path: str = None):
+        if not hasattr(self, 'initialized') or module_size != self.module_size:
+            self.whisper_model_path = whisper_model_path or DEFAULT_WHISPER_MODEL_PATH
+            self.module_size = module_size
+            self.whisper_model = whisper.load_model(self.module_size, download_root=self.whisper_model_path)
 def get_whisper_model(module_size: str = "base", whisper_model_path: str = None):
-    whisper_model_path = whisper_model_path or DEFAULT_WHISPER_MODEL_PATH
-    return whisper.load_model(module_size, download_root=whisper_model_path)
+    whisper_mgr = whisperManager(module_size=module_size,whisper_model_path=whisper_model_path)
+    return whisper_mgr.whisper_model
 
 
 def whisper_transcribe(
